@@ -233,25 +233,33 @@ SIGN_SEAL - 签署印章控件
 SIGN_DATE - 签署日期控件
 SIGN_SIGNATURE - 手写签名控件
         :type ComponentType: str
-        :param ComponentWidth: 参数控件宽度，单位px
+        :param ComponentWidth: 参数控件宽度，单位pt
         :type ComponentWidth: float
-        :param ComponentHeight: 参数控件高度，单位px
+        :param ComponentHeight: 参数控件高度，单位pt
         :type ComponentHeight: float
         :param ComponentPage: 参数控件所在页码，取值为：1-N
         :type ComponentPage: int
-        :param ComponentPosX: 参数控件X位置，单位px
+        :param ComponentPosX: 参数控件X位置，单位pt
         :type ComponentPosX: float
-        :param ComponentPosY: 参数控件Y位置，单位px
+        :param ComponentPosY: 参数控件Y位置，单位pt
         :type ComponentPosY: float
         :param FileIndex: 控件所属文件的序号（模板中的resourceId排列序号，取值为：0-N）
         :type FileIndex: int
-        :param ComponentId: 控件编号
+        :param ComponentId: GenerateMode==KEYWORD 指定关键字
         :type ComponentId: str
-        :param ComponentName: 控件名称
+        :param ComponentName: GenerateMode==FIELD 指定表单域名称
         :type ComponentName: str
         :param ComponentRequired: 是否必选，默认为false
         :type ComponentRequired: bool
-        :param ComponentExtra: 参数控件样式
+        :param ComponentExtra: 扩展参数：
+ComponentType为SIGN_SIGNATURE类型可以控制签署方式
+{“ComponentTypeLimit”: [“xxx”]}
+xxx可以为：
+HANDWRITE – 手写签名
+BORDERLESS_ESIGN – 自动生成无边框腾讯体
+OCR_ESIGN -- AI智能识别手写签名
+ESIGN -- 个人印章类型
+如：{“ComponentTypeLimit”: [“BORDERLESS_ESIGN”]}
         :type ComponentExtra: str
         :param ComponentRecipientId: 控件关联的签署人ID
         :type ComponentRecipientId: str
@@ -265,6 +273,10 @@ KEYWORD 关键字，使用ComponentId指定关键字
         :type GenerateMode: str
         :param ComponentDateFontSize: 日期控件类型字号
         :type ComponentDateFontSize: int
+        :param OffsetX: 指定关键字时横坐标偏移量
+        :type OffsetX: float
+        :param OffsetY: 指定关键字时纵坐标偏移量
+        :type OffsetY: float
         """
         self.ComponentType = None
         self.ComponentWidth = None
@@ -282,6 +294,8 @@ KEYWORD 关键字，使用ComponentId指定关键字
         self.IsFormType = None
         self.GenerateMode = None
         self.ComponentDateFontSize = None
+        self.OffsetX = None
+        self.OffsetY = None
 
 
     def _deserialize(self, params):
@@ -301,6 +315,8 @@ KEYWORD 关键字，使用ComponentId指定关键字
         self.IsFormType = params.get("IsFormType")
         self.GenerateMode = params.get("GenerateMode")
         self.ComponentDateFontSize = params.get("ComponentDateFontSize")
+        self.OffsetX = params.get("OffsetX")
+        self.OffsetY = params.get("OffsetY")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1199,7 +1215,7 @@ class UploadFilesRequest(AbstractModel):
         :param Caller: 调用方信息
         :type Caller: :class:`tencentcloud.ess.v20201111.models.Caller`
         :param BusinessType: 文件对应业务类型，用于区分文件存储路径：
-1. TEMPLATE - 模版； 文件类型：.pdf/.html
+1. TEMPLATE - 模板； 文件类型：.pdf/.html
 2. DOCUMENT - 签署过程及签署后的合同文档 文件类型：.pdf/.html
 3. FLOW - 签署过程 文件类型：.pdf/.html
 4. SEAL - 印章； 文件类型：.jpg/.jpeg/.png
